Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(256)

Unified Diff: handler/mac/crash_report_upload_thread.cc

Issue 1009743004: Update crashpad_handler man page to document all options (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | handler/mac/crashpad_handler.ad » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: handler/mac/crash_report_upload_thread.cc
diff --git a/handler/mac/crash_report_upload_thread.cc b/handler/mac/crash_report_upload_thread.cc
index a4e4607d0c57bf4d6c96a1ad85e9bde5b0b02e93..5333c78d180e02d476dfb4a3434515220363e0a2 100644
--- a/handler/mac/crash_report_upload_thread.cc
+++ b/handler/mac/crash_report_upload_thread.cc
@@ -226,9 +226,11 @@ void CrashReportUploadThread::ProcessPendingReport(
Settings* const settings = database_->GetSettings();
bool uploads_enabled;
- if (!settings->GetUploadsEnabled(&uploads_enabled) || !uploads_enabled) {
- // If uploads are disabled or the upload-enabled state can’t be determined,
- // don’t attempt to upload the new report.
+ if (!settings->GetUploadsEnabled(&uploads_enabled) ||
+ !uploads_enabled ||
+ url_.empty()) {
+ // If the upload-enabled state can’t be determined, uploads are disabled, or
+ // there’s no URL to upload to, don’t attempt to upload the new report.
database_->SkipReportUpload(report.uuid);
return;
}
« no previous file with comments | « no previous file | handler/mac/crashpad_handler.ad » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698